@@ -20,7 +20,9 @@ class PhpProvider:
     def __init__(self, path: Path, custom_commands: CustomCommands):
         self.path = path
         self.custom_commands = custom_commands
-        self.has_composer = _exists(self.path, "composer.json", "composer.lock")
+        self.has_composer = _exists(self.path, "composer.json", "composer.lock") or (
+            custom_commands.install and custom_commands.install.startswith("composer ")
+        )
 
     @classmethod
     def name(cls) -> str:
@@ -40,6 +42,8 @@ class PhpProvider:
             return DetectResult(cls.name(), 10)
         if custom_commands.start and custom_commands.start.startswith("php "):
             return DetectResult(cls.name(), 70)
+        if custom_commands.install and custom_commands.install.startswith("composer "):
+            return DetectResult(cls.name(), 30)
         return None
 
     def initialize(self) -> None:
@@ -48,9 +52,6 @@ class PhpProvider:
     def serve_name(self) -> str:
         return self.path.name
 
-    def provider_kind(self) -> str:
-        return "php"
-
     def platform(self) -> Optional[str]:
         return None
 
@@ -115,7 +116,9 @@ class PhpProvider:
             }
         elif _exists(self.path, "index.php"):
             return {"start": '"php -S localhost:{} -t {}".format(PORT, app["serve"])'}
-        return {}
+        return {
+            "start": '"php -S localhost:{} -t {}".format(PORT, app["serve"])',
+        }
 
     def mounts(self) -> list[MountSpec]:
         return [
