@@ -43,11 +43,8 @@ class WordPressProvider(PhpProvider):
     def serve_name(self) -> str:
         return self.path.name
 
-    def provider_kind(self) -> str:
-        return "php"
-
     def platform(self) -> Optional[str]:
-        return "wordpress"
+        return None
 
     def dependencies(self) -> list[DependencySpec]:
         return [
@@ -81,7 +78,7 @@ class WordPressProvider(PhpProvider):
     def commands(self) -> Dict[str, str]:
         commands = super().commands()
         return {
-            "wp": '"php {}/wp-cli.phar --allow-root --path={}".format(assets["serve"], app["serve"])',
+            # "wp": '"php {}/wp-cli.phar --allow-root --path={}".format(assets["serve"], app["serve"])',
             "after_deploy": '"bash {}/setup-wp.sh".format(assets["serve"])',
             **commands,
         }
